@@ -12,11 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import url
-from magnum_ui.content.clusters import views
+from django.urls import re_path
+from django.utils.translation import ugettext_lazy as _
+from horizon.browsers import views
+from magnum_ui.content.clusters import panel
 
 
+title = _("Container Infra - Clusters")
+page_title = panel.Clusters.name
 urlpatterns = [
-    url(r'^[0-9a-f\-]{36}$', views.IndexView.as_view(), name='detail'),
-    url(r'^$', views.IndexView.as_view(), name='index'),
+    re_path(r'^$', views.AngularIndexView.as_view(
+            title=title, page_title=page_title),
+            name='index'),
 ]
